@@ -272,8 +272,9 @@ rpn(unsigned int nw, char **w, char ** result)
 	unsigned int    NW;
 	char           *W[MAX_nword];
 	operator_name   oper;
-	double          operand_value;
-	*result = "";
+	double          operand_value = 0.0; // should be set below, actually (remove warning)
+	*result = new char[1];
+	strcpy(*result, "");
 	if (nw < 1) {
 		if (((unsigned) superuser()) & FLAG_RPN) printf("rpn() go stack underflow\n");
 		return STACK_UNDERFLOW;
